==> baseui-4.3.0.tgz: package/es/accordion/__tests__/styled-components.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../index");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
var styledComponents = [[_index.StyledRoot, 'StyledRoot'], [_index.StyledPanelContainer, 'StyledPanelContainer'], [_index.StyledHeader, 'StyledHeader'], [_index.StyledToggleIcon, 'StyledToggleIcon'], [_index.StyledContent, 'StyledContent']];
describe('Accordion styled components', function () {
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = (0, _enzyme.shallow)(_react.default.createElement(Component, {
      $disabled: false,
      $expanded: true
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded is set to true"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = (0, _enzyme.shallow)(_react.default.createElement(Component, {
      $disabled: false,
      $expanded: false
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded is set to false"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = (0, _enzyme.shallow)(_react.default.createElement(Component, {
      $disabled: true,
      $expanded: false
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when not expanded and disabled is set to true"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = (0, _enzyme.shallow)(_react.default.createElement(Component, {
      $disabled: true,
      $expanded: true
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded and disabled is set to true"));
  });
});

==> baseui-5.10.0.tgz: package/es/accordion/__tests__/styled-components.test.js <==
/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import React from 'react';
import { shallow } from 'enzyme';
import { StyledRoot, StyledPanelContainer, StyledHeader, StyledToggleIcon, StyledContent } from '../index.js';
var styledComponents = [[StyledRoot, 'StyledRoot'], [StyledPanelContainer, 'StyledPanelContainer'], [StyledHeader, 'StyledHeader'], [StyledToggleIcon, 'StyledToggleIcon'], [StyledContent, 'StyledContent']];
describe('Accordion styled components', function () {
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = shallow(React.createElement(Component, {
      $disabled: false,
      $expanded: true
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded is set to true"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = shallow(React.createElement(Component, {
      $disabled: false,
      $expanded: false
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded is set to false"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = shallow(React.createElement(Component, {
      $disabled: true,
      $expanded: false
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when not expanded and disabled is set to true"));
  });
  test.each(styledComponents)('Basic render', function (Component, name) {
    var component = shallow(React.createElement(Component, {
      $disabled: true,
      $expanded: true
    }));
    expect(component.instance().getStyles()).toMatchSnapshot("".concat(name, " has correct styles when expanded and disabled is set to true"));
  });
});
